.. HNP documentation master file, created by
   sphinx-quickstart on Mon Jan 23 09:08:39 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
   :start-after: start-in-sphinx-home-docs
   :end-before: end-in-sphinx-home-docs


===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Home <self>
   getting_started
   config
   sinergym_tut
   beobench_tut
   api
   credits_license
